import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot'; // Importing a custom scatter plot function

// URL of the dataset
const csvUrl =
  'https://gist.githubusercontent.com/NandithaSura/784eef9bc929bc7f7eae9627b8fd74d4/raw/2654abeb912711ee2a3741ecad4d03240fa850bb/ice7.csv';

// Function to parse each row of the CSV data
const parseRow = (d) => {
  d.mpg = +d.mpg; // Convert mpg to a number
  d.hp = +d.hp; // Convert hp to a number
  d.cyl = +d.cyl; // Convert cyl to a number
  d.disp = +d.disp; // Convert disp to a number
  return d;
};

// Set the SVG dimensions based on the window size
const width = window.innerWidth;
const height = window.innerHeight - 100; // Subtracting 100 for some margin
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// Async function to load and render the scatter plot
const main = async () => {
  // Create a scatter plot instance
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow)) // Load and parse CSV data
    .xValue((d) => d.hp) // Set x-value accessor to 'hp'
    .yValue((d) => d.mpg) // Set y-value accessor to 'mpg'
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    }) // Set margin
    .radius(5); // Set circle radius

  // Call the scatter plot function on the SVG
  svg.call(plot);

  // Set dynamic axes every second
  const columns = ['hp', 'mpg', 'cyl', 'disp']; // Columns to cycle through
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]); // Cycle through columns for x-value
    svg.call(plot);
    i++;
  }, 1000);

  // Append x-axis label
  svg
    .append('text')
    .attr('class', 'x-label')
    .attr('text-anchor', 'middle')
    .attr('x', width / 2)
    .attr('y', height - 10)
    .text('Horsepower');

  // Append y-axis label
  svg
    .append('text')
    .attr('class', 'y-label')
    .attr('text-anchor', 'middle')
    .attr('x', -height / 2)
    .attr('y', 10)
    .attr('transform', 'rotate(-90)')
    .text('Miles per Gallon');
};

main(); // Call the main function to start the visualization
